==> vininfo-0.2.0.tar.gz: vininfo-0.2.0/vininfo/dicts/wmi.py <==
# -*- encoding: utf-8 -*-
from __future__ import unicode_literals

from ..brands import Lada, Nissan


WMI = {
    'AAV': 'Volkswagen',
    'AHT': 'Toyota',
    'AFA': 'Ford',
    'CL9': 'Wallyscar',
    'JA': 'Isuzu',
    'JC1': 'Fiat Automobiles/Mazda',
    'JF': 'Fuji Heavy Industries',
    'JHG': 'Honda',
    'JHL': 'Honda',
    'JHM': 'Honda',
    'JMB': 'Mitsubishi',
    'JK': 'Kawasaki',
    'JM': 'Mazda',
    'JN': Nissan(),
    'JS': 'Suzuki',
    'JT': 'Toyota',
    'JY': 'Yamaha',
    'KL': 'Daewoo/GM Korea',
    'KM': 'Hyundai',
    'KN': 'Kia',
    'KNM': 'Renault Samsung',
    'KPA': 'SsangYong',
    'KPT': 'SsangYong',
    'L56': 'Renault Samsung',
    'L5Y': 'Merato Motorcycle Taizhou Zhongneng',
    'L6T': 'Geely',
    'LBE': 'Beijing Hyundai',
    'LBV': 'BMW Brilliance',
    'LC0': 'BYD Bus',
    'LDY': 'Zhongtong Coach',
    'LDC': 'Dongfeng Peugeot-Citroën',
    'LE4': 'Beijing Benz',
    'LFM': 'FAW Toyota',
    'LFP': 'FAW Car',
    'LFV': 'FAW-Volkswagen',
    'LGB': 'Dongfeng Nissan',
    'LGH': 'Dong Feng (DFM), China',
    'LGJ': 'Dongfeng Fengshen',
    'LGW': 'Great Wall (Havel)',
    'LGX': 'BYD Auto',
    'LH1': 'FAW Haima',
    'LHG': 'Guangzhou Honda',
    'LJ1': 'JAC',
    'LJD': 'Dongfeng Yueda Kia',
    'LLV': 'Lifan',
    'LMG': 'GAC Trumpchi',
    'LPA': 'Changan PSA (DS Automobiles)',
    'LS5': 'Changan Suzuki',
    'LSG': 'SAIC General Motors',
    'LSJ': 'SAIC MG',
    'LSV': 'SAIC Volkswagen',
    'LTV': 'FAW Toyota (Tianjin)',
    'LVG': 'GAC Toyota',
    'LVH': 'Dongfeng Honda',
    'LVR': 'Changan Mazda',
    'LVS': 'Changan Ford',
    'LVV': 'Chery',
    'LWV': 'GAC Fiat',
    'LZW': 'SAIC GM Wuling',
    'LZY': 'Yutong',
    'MM0': 'Mazda',
    'MS0': 'KIA Myanmar',
    'NMT': 'Toyota',
    'NM0': 'Ford Otosan',
    'PL1': 'Proton',
    'SAJ': 'Jaguar',
    'SAL': 'Land Rover',
    'SAR': 'Rover',
    'SAT': 'Triumph',
    'SB1': 'Toyota',
    'SCC': 'Lotus Cars',
    'SCF': 'Aston Martin Lagonda Limited',
    'SCE': 'DeLorean',
    'SFD': 'Alexander Dennis',
    'SHH': 'Honda',
    'SHS': 'Honda',
    'SJN': Nissan(),
    'TCC': 'Micro Compact Car AG (SMART 1998-1999)',
    'TMA': 'Hyundai',
    'TMB': 'Škoda',
    'TRU': 'Audi',
    'TSM': 'Suzuki',
    'U5Y': 'Kia',
    'UU': 'Dacia',
    'VA0': 'ÖAF',
    'VF1': 'Renault',
    'VF2': 'Renault',
    'VF3': 'Peugeot',
    'VF4': 'Talbot',
    'VF5': 'Iveco Unic SA',
    'VF6': 'Renault Trucks/Volvo',
    'VF7': 'Citroën',
    'VF8': 'Matra/Talbot/Simca',
    'VF9': 'Bugatti',
    'VFE': 'IvecoBus',
    'VNK': 'Toyota',
    'VSS': 'SEAT',
    'VV9': 'Tauro Sport Auto',
    'WAG': 'Neoplan',
    'WAU': 'Audi',
    'WAP': 'Alpina',
    'WBA': 'BMW',
    'WBS': 'BMW M',
    'WBX': 'BMW',
    'WDB': 'Mercedes-Benz',
    'WDC': 'DaimlerChrysler AG/Daimler AG',
    'WDD': 'DaimlerChrysler AG/Daimler AG',
    'WMX': 'DaimlerChrysler AG/Daimler AG',
    'WEB': 'EvoBus',
    'WF0': 'Ford of Europe',
    'WJM': 'Iveco',
    'WJR': 'Irmscher',
    'WKK': 'Karl Kässbohrer Fahrzeugwerke',
    'WMA': 'MAN',
    'WME': 'Smart',
    'WMW': 'Mini',
    'WP0': 'Porsche car',
    'WP1': 'Porsche SUV',
    'WUA': 'Quattro',
    'WVG': 'Volkswagen',
    'WVW': 'Volkswagen',
    'WV1': 'Volkswagen Commercial Vehicles',
    'WV2': 'Volkswagen Commercial Vehicles',
    'W09': 'Ruf Automobile',
    'W0L': 'Opel/Vauxhall',
    'W0SV': 'Opel Special Vehicles',
    'XLR': 'DAF Trucks',
    'XTA': Lada('AvtoVAZ'),
    'YK1': 'Saab',
    'YS2': 'Scania, Södertälje',
    'YS3': 'Saab',
    'YS4': 'Scania, Katrineholm',
    'YTN': 'Saab NEVS',
    'YV1': 'Volvo Cars',
    'YV2': 'Volvo Trucks',
    'YV3': 'Volvo Buses',
    'ZA9': 'Bugatti',
    'ZAM': 'Maserati',
    'ZAR': 'Alfa Romeo',
    'ZCF': 'Iveco',
    'ZFA': 'Fiat Automobiles',
    'ZFF': 'Ferrari',
    'ZGA': 'IvecoBus',
    'ZHW': 'Lamborghini',
    'ZLA': 'Lancia',
    '1B': 'Dodge',
    '1C': 'Chrysler',
    '1F': 'Ford',
    '1G': 'General Motors',
    '1G1': 'Chevrolet',
    '1G3': 'Oldsmobile',
    '1G6': 'Cadillac',
    '1G9': 'Google',
    '1GC': 'Chevrolet',
    '1GM': 'Pontiac',
    '1H': 'Honda',
    '1J': 'Jeep',
    '1L': 'Lincoln',
    '1M': 'Mercury',
    '1N': Nissan(),
    '1VW': 'Volkswagen',
    '1YV': 'Mazda',
    '1ZV': 'Auto Alliance International',
    '2DG': 'Ontario Drive & Gear',
    '2F': 'Ford',
    '2G': 'General Motors',
    '2G1': 'Chevrolet',
    '2G2': 'Pontiac',
    '2G9': 'Gnome Homes',
    '2HG': 'Honda',
    '2HH': 'Acura',
    '2HJ': 'Honda',
    '2HK': 'Honda',
    '2HM': 'Hyundai',
    '2M': 'Mercury',
    '2T': 'Toyota',
    '3F': 'Ford',
    '3G': 'General Motors',
    '3H': 'Honda',
    '3HM': 'Honda',
    '3KP': 'Kia',
    '3N': Nissan(),
    '3VW': 'Volkswagen',
    '4F': 'Mazda',
    '4J': 'Mercedes-Benz',
    '4M': 'Mercury',
    '4S': 'Subaru-Isuzu Automotive',
    '4S6': 'Honda',
    '4T': 'Toyota',
    '4US': 'BMW',
    '5F': 'Honda',
    '5J6': 'Honda',
    '5L': 'Lincoln',
    '5N1': Nissan(),
    '5NM': 'Hyundai',
    '5NP': 'Hyundai',
    '5T': 'Toyota',
    '5U': 'BMW',
    '5X': 'Hyundai/Kia',
    '5YJ': 'Tesla',
    '55': 'Mercedes-Benz',
    '6F': 'Ford',
    '6G': 'General Motors',
    '6G1': 'Chevrolet',
    '6G2': 'Pontiac',
    '6H': 'Holden',
    '6MM': 'Mitsubishi',
    '6T1': 'Toyota',
    '7A3': 'Honda',
    '8AP': 'Fiat',
    '8AF': 'Ford',
    '8AG': 'General Motors',
    '8AW': 'Volkswagen',
    '8AJ': 'Toyota',
    '8A1': 'Renault',
    '8AC': 'Mercedes Benz',
    '8BC': 'Citroën',
    '8AD': 'Peugeot',
    '8C3': 'Honda',
    '8AT': 'Iveco',
    '9BD': 'Fiat Automóveis',
    '9BG': 'General Motors',
    '9BW': 'Volkswagen',
    '9BF': 'Ford',
    '93H': 'Honda',
    '9BR': 'Toyota',
    '936': 'Peugeot',
    '935': 'Citroën',
    '93Y': 'Renault',
    '93X': 'Souza Ramos - Mitsubishi / Suzuki',
    '9BH': 'Hyundai Motor Company / Hyundai',
    '95P': 'CAOA / Hyundai',
    '94D': Nissan(),
    '98R': 'Chery',
    '988': 'Jeep',
    '98M': 'BMW',
    '9BM': 'Mercedes Benz',
    '99A': 'Audi',
    '99J': 'JLR Jaguar Land Rover',
    '9C2': 'Honda Motorcycles',
    '9C6': 'Yamaha',
    '9CD': 'Suzuki Motorcycles',
    '93W': 'Fiat Professional',
    '93Z': 'Iveco',
    '953': 'VW Trucks / MAN',
    '9BS': 'Scania',
    '9BV': 'Volvo Trucks',
    '9UJ': 'Chery',
    '9UK': 'Lifan',
    '9UW': 'Kia',

    'LKL': 'Suzhou King Long',
    'LSY': 'Brilliance Zhonghua',
    'LZM': 'MAN',
    'LZE': 'Isuzu Guangzhou',
    'LZG': 'Shaanxi Automobile Group',
    'MA1': 'Mahindra',
    'MA3': 'Suzuki',
    'MA7': 'Honda Siel Cars',
    'MAL': 'Hyundai',
    'MC2': 'Volvo Eicher commercial vehicles limited.',
    'MHR': 'Honda',
    'MNB': 'Ford',
    'MNT': Nissan(),
    'MMB': 'Mitsubishi',
    'MMM': 'Chevrolet',
    'MMT': 'Mitsubishi',
    'MM8': 'Mazda',
    'MPA': 'Isuzu',
    'MP1': 'Isuzu',
    'MRH': 'Honda',
    'MR0': 'Toyota',
    'NLE': 'Mercedes-Benz Turk Truck',
    'NM4': 'Tofas Turk',
    'PE1': 'Ford',
    'PE3': 'Mazda',
    'SCA': 'Rolls Royce',
    'SDB': 'Peugeot UK',
    'SU9': 'Solaris Bus & Coach',
    'TK9': 'SOR',
    'TDM': 'QUANTYA Swiss Electric Movement',
    'TMK': 'Karosa',
    'TMP': 'Škoda trolleybuses',
    'TMT': 'Tatra',
    'TM9': 'Škoda trolleybuses',
    'TN9': 'Karosa',
    'TRA': 'Ikarus Bus',
    'TSE': 'Ikarus Egyedi Autobuszgyar',
    'UU1': 'Renault Dacia',
    'VLU': 'Scania',
    'VNE': 'Irisbus',
    'VSE': 'Suzuki / Santana Motors',
    'VSK': Nissan(),
    'VSX': 'Opel',
    'VS6': 'Ford',
    'VS9': 'Carrocerias Ayats',
    'VWV': 'Volkswagen',
    'VX1': 'Zastava / Yugo',
    'XL9': 'Spyker',
    'XMC': 'Mitsubishi (NedCar)',
    'YV4': 'Volvo Cars',
    'ZAP': 'Piaggio/Vespa/Gilera',
    'ZCG': 'Cagiva SpA',
    'ZDM': 'Ducati Motor Holdings SpA',
    'ZDF': 'Ferrari Dino',
    'ZD4': 'Aprilia',
    'ZFC': 'Fiat V.I.',
    'ZOM': 'OM',
    '1D3': 'Dodge',
    '1FU': 'Freightliner',
    '1FV': 'Freightliner',
    '1F9': 'FWD Corp.',

    '1GT': 'GMC Truck',
    '1G2': 'Pontiac',
    '1G4': 'Buick',
    '1G8': 'Saturn',
    '1HD': 'Harley-Davidson',
    '1J4': 'Jeep',
    '1ME': 'Mercury',
    '1M1': 'Mack Truck',
    '1M2': 'Mack Truck',
    '1M3': 'Mack Truck',
    '1M4': 'Mack Truck',
    '1M9': 'Mynatt Truck & Equipment',
    '1NX': 'NUMMI',
    '1P3': 'Plymouth',
    '1R9': 'Roadrunner Hay Squeeze',
    '1XK': 'Kenworth',
    '1XP': 'Peterbilt',
    '2C3': 'Chrysler',
    '2CN': 'CAMI',
    '2D3': 'Dodge',
    '2FT': 'Ford Motor Company',
    '2FU': 'Freightliner',
    '2FV': 'Freightliner',
    '2FZ': 'Sterling',
    '2G3': 'Oldsmobile',
    '2G4': 'Buick',
    '2NV': 'Nova Bus',
    '2P3': 'Plymouth',
    '2V4': 'Volkswagen',
    '2W': 'Western Star',
    '3D3': 'Dodge',
    '3P3': 'Plymouth Mexico',
    '4RK': 'Nova Bus',
    '4UZ': 'Frt-Thomas Bus',
    '4V': 'Volvo',
    '6AB': 'MAN',
    '6F4': Nissan('Nissan Motor Company'),
    '6F5': 'Kenworth',
    '6FP': 'Ford Motor Company',
    '6H8': 'General Motors-Holden',
    '8GG': 'Chevrolet',
    '8GD': 'Peugeot',
    '8AK': 'Suzuki',
    '93U': 'Audi',
    '93R': 'Toyota',
    '9FB': 'Renault',
}

==> vininfo-1.2.0.tar.gz: vininfo-1.2.0/vininfo/dicts/wmi.py <==
# -*- encoding: utf-8 -*-
from __future__ import unicode_literals

from ..brands import Lada, Nissan, Opel, Renault


WMI = {
    '1B': 'Dodge',
    '1C': 'Chrysler',
    '1D': 'Dodge',
    '1F': 'Ford',
    '1F9': 'FWD Corp.',
    '1FU': 'Freightliner',
    '1FV': 'Freightliner',
    '1G': 'General Motors',
    '1G1': 'Chevrolet',
    '1G2': 'Pontiac',
    '1G3': 'Oldsmobile',
    '1G4': 'Buick',
    '1G6': 'Cadillac',
    '1G8': 'Saturn',
    '1G9': 'Google',
    '1GB': 'Chevrolet USA',
    '1GC': 'Chevrolet',
    '1GM': 'Pontiac',
    '1GN': 'Chevrolet USA',
    '1GT': 'GMC Truck',
    '1GY': 'Cadillac',
    '1H': 'Honda',
    '1HD': 'Harley-Davidson',
    '1J': 'Jeep',
    '1L': 'Lincoln',
    '1M': 'Mercury',
    '1M1': 'Mack Truck',
    '1M2': 'Mack Truck',
    '1M3': 'Mack Truck',
    '1M4': 'Mack Truck',
    '1M9': 'Mynatt Truck & Equipment',
    '1ME': 'Mercury',
    '1N': Nissan(),
    '1NX': 'NUMMI',
    '1P3': 'Plymouth',
    '1R9': 'Roadrunner Hay Squeeze',
    '1V1': 'Volkswagen USA (Commercials)',
    '1VW': 'Volkswagen',
    '1XK': 'Kenworth',
    '1XP': 'Peterbilt',
    '1YV': 'Mazda',
    '1Z7': 'Mitsubishi',
    '1ZV': 'Auto Alliance International',
    '2A4': 'Chrysler Canada',
    '2A8': 'Chrysler Canada',
    '2B3': 'Dodge Canada',
    '2C3': 'Chrysler',
    '2C4': 'Chrysler Canada',
    '2CN': 'CAMI',
    '2CT': 'General Motors',
    '2D3': 'Dodge',
    '2D4': 'Dodge Canada',
    '2D8': 'Dodge Canada',
    '2DG': 'Ontario Drive & Gear',
    '2F': 'Ford',
    '2FT': 'Ford Motor Company',
    '2FU': 'Freightliner',
    '2FV': 'Freightliner',
    '2FZ': 'Sterling',
    '2G': 'General Motors',
    '2G1': 'Chevrolet',
    '2G2': 'Pontiac',
    '2G3': 'Oldsmobile',
    '2G4': 'Buick',
    '2G6': 'Cadillac',
    '2G9': 'Gnome Homes',
    '2GC': 'Chevrolet Canada',
    '2GN': 'Chevrolet Canada',
    '2H': 'Honda',
    '2HH': 'Acura',
    '2HM': 'Hyundai',
    '2HN': 'Acura',
    '2L': 'Lincoln',
    '2M': 'Mercury',
    '2NV': 'Nova Bus',
    '2P3': 'Plymouth',
    '2S3': 'Suzuki Canada',
    '2T': 'Toyota',
    '2T2': 'Lexus Canada',
    '2V4': 'Volkswagen',
    '2V8': 'Volkswagen',
    '2W': 'Western Star',
    '3A': 'Chrysler Mexico',
    '3B7': 'Dodge Mexico',
    '3C': 'Chrysler',
    '3C4': 'Dodge Mexico',
    '3CZ': 'Honda Mexico',
    '3D': 'Dodge',
    '3F': 'Ford',
    '3G': 'General Motors',
    '3GC': 'Chevrolet Mexico',
    '3GN': 'Chevrolet Mexico',
    '3GY': 'Cadillac',
    '3H': 'Honda',
    '3KP': 'Kia',
    '3LN': 'Lincoln',
    '3ME': 'Mercury Mexico',
    '3MY': 'Mazda Mexico',
    '3MZ': 'Mazda Mexico',
    '3N': Nissan(),
    '3P3': 'Plymouth Mexico',
    '3TM': 'Toyota Mexico',
    '3VW': 'Volkswagen',
    '4A': 'Mitsubishi',
    '4F': 'Mazda',
    '4GD': Opel(),
    '4J': 'Mercedes-Benz',
    '4M': 'Mercury',
    '4RK': 'Nova Bus',
    '4S': 'Subaru-Isuzu Automotive',
    '4S6': 'Honda',
    '4T': 'Toyota',
    '4US': 'BMW',
    '4UZ': 'Frt-Thomas Bus',
    '4V': 'Volvo',
    '5F': 'Honda',
    '5FR': 'Acura',
    '5GA': 'Buick',
    '5GN': 'Hummer',
    '5GR': 'Hummer',
    '5GT': 'Hummer',
    '5GZ': 'Saturn',
    '5J6': 'Honda',
    '5J8': 'Acura',
    '5KB': 'Honda',
    '5L': 'Lincoln',
    '5N1': Nissan(),
    '5N3': Nissan('Infiniti'),
    '5NM': 'Hyundai',
    '5NP': 'Hyundai',
    '5T': 'Toyota',
    '5U': 'BMW',
    '5X': 'Hyundai/Kia',
    '5XX': 'Kia',
    '5XY': 'Kia',
    '5Y2': 'Pontiac',
    '5YF': 'Toyota',
    '5YJ': 'Tesla',
    '5YM': 'BMW',
    '6AB': 'MAN',
    '6F': 'Ford',
    '6F4': Nissan('Nissan Motor Company'),
    '6F5': 'Kenworth',
    '6FP': 'Ford Motor Company',
    '6G': 'General Motors',
    '6G1': 'Chevrolet',
    '6G2': 'Pontiac',
    '6G3': 'Chevrolet Australia',
    '6H': 'Holden',
    '6H8': 'General Motors-Holden',
    '6MM': 'Mitsubishi',
    '6T1': 'Toyota',
    '7A3': 'Honda',
    '8A1': Renault(),
    '8AC': 'Mercedes Benz',
    '8AD': 'Peugeot',
    '8AF': 'Ford',
    '8AG': 'General Motors',
    '8AJ': 'Toyota',
    '8AK': 'Suzuki',
    '8AP': 'Fiat',
    '8AT': 'Iveco',
    '8AW': 'Volkswagen',
    '8BC': 'Citroën',
    '8BR': 'Mercedes-Benz Argentina',
    '8BT': 'Mercedes-Benz Argentina',
    '8C3': 'Honda',
    '8GD': 'Peugeot',
    '8GG': 'Chevrolet',
    '9BD': 'Fiat Automóveis',
    '9BF': 'Ford',
    '9BG': 'General Motors',
    '9BH': 'Hyundai Motor Company / Hyundai',
    '9BM': 'Mercedes Benz',
    '9BR': 'Toyota',
    '9BS': 'Scania',
    '9BV': 'Volvo Trucks',
    '9BW': 'Volkswagen',
    '9C2': 'Honda Motorcycles',
    '9C6': 'Yamaha',
    '9CD': 'Suzuki Motorcycles',
    '9FB': Renault(),
    '9UJ': 'Chery',
    '9UK': 'Lifan',
    '9UW': 'Kia',
    '19': 'Acura',
    '19X': 'Honda',
    '54D': 'Chevrolet',  # Spartan
    '55': 'Mercedes-Benz',
    '55S': 'Mercedes-Benz',
    '58A': 'Lexus',
    '93H': 'Honda',
    '93R': 'Toyota',
    '93U': 'Audi',
    '93V': 'Audi Brazil',
    '93W': 'Fiat Professional',
    '93X': 'Souza Ramos - Mitsubishi / Suzuki',
    '93Y': Renault(),
    '93Z': 'Iveco',
    '94D': Nissan(),
    '95P': 'CAOA / Hyundai',
    '98M': 'BMW',
    '98R': 'Chery',
    '99A': 'Audi',
    '99J': 'JLR Jaguar Land Rover',
    '935': 'Citroën',
    '936': 'Peugeot',
    '953': 'VW Trucks / MAN',
    '988': 'Jeep',
    'AAV': 'Volkswagen',
    'AFA': 'Ford',
    'AHT': 'Toyota',
    'CL9': 'Wallyscar',
    'GA1': Renault(),
    'JA': 'Isuzu',
    'JA3': 'Mitsubishi',
    'JA4': 'Mitsubishi',
    'JB3': 'Dodge',
    'JC1': 'Fiat Automobiles/Mazda',
    'JF': 'Fuji Heavy Industries',
    'JGN': 'Chevrolet',
    'JH': 'Honda',
    'JH4': 'Acura',
    'JK': 'Kawasaki',
    'JM': 'Mazda',
    'JMB': 'Mitsubishi',
    'JN': Nissan(),
    'JNK': Nissan('Infiniti'),
    'JNR': Nissan('Infiniti'),
    'JNT': Nissan('Infiniti'),
    'JNX': Nissan('Infiniti'),
    'JS': 'Suzuki',
    'JT': 'Toyota',
    'JTH': 'Lexus',
    'JTJ': 'Lexus',
    'JTK': 'Scion',
    'JTL': 'Scion',
    'JY': 'Yamaha',
    'KL': 'Daewoo/GM Korea',
    'KL1': 'Chevrolet',
    'KL4': 'Buick',
    'KL7': 'Chevrolet',
    'KL8': 'Chevrolet',
    'KM': 'Hyundai',
    'KN': 'Kia',
    'KNM': Renault('Renault Samsung'),
    'KP': 'SsangYong',
    'L5Y': 'Merato Motorcycle Taizhou Zhongneng',
    'L6T': 'Geely',
    'L56': Renault('Renault Samsung'),
    'LBE': 'Beijing Hyundai',
    'LBV': 'BMW Brilliance',
    'LC0': 'BYD Bus',
    'LDC': 'Dongfeng Peugeot-Citroën',
    'LDY': 'Zhongtong Coach',
    'LE4': 'Beijing Benz',
    'LFM': 'FAW Toyota',
    'LFP': 'FAW Car',
    'LFV': 'FAW-Volkswagen',
    'LGB': 'Dongfeng Nissan',
    'LGH': 'Dong Feng (DFM), China',
    'LGJ': 'Dongfeng Fengshen',
    'LGW': 'Great Wall (Havel)',
    'LGX': 'BYD Auto',
    'LH1': 'FAW Haima',
    'LHG': 'Guangzhou Honda',
    'LJ1': 'JAC',
    'LJD': 'Dongfeng Yueda Kia',
    'LKL': 'Suzhou King Long',
    'LLV': 'Lifan',
    'LMG': 'GAC Trumpchi',
    'LPA': 'Changan PSA (DS Automobiles)',
    'LRB': 'Buick China',
    'LS5': 'Changan Suzuki',
    'LSG': 'SAIC General Motors',
    'LSJ': 'SAIC MG',
    'LSV': 'SAIC Volkswagen',
    'LSY': 'Brilliance Zhonghua',
    'LTV': 'FAW Toyota (Tianjin)',
    'LVG': 'GAC Toyota',
    'LVH': 'Dongfeng Honda',
    'LVR': 'Changan Mazda',
    'LVS': 'Changan Ford',
    'LVV': 'Chery',
    'LWV': 'GAC Fiat',
    'LYV': 'Volvo China',
    'LZE': 'Isuzu Guangzhou',
    'LZG': 'Shaanxi Automobile Group',
    'LZM': 'MAN',
    'LZW': 'SAIC GM Wuling',
    'LZY': 'Yutong',
    'MA1': 'Mahindra',
    'MA3': 'Suzuki',
    'MA7': 'Honda Siel Cars',
    'MAL': 'Hyundai',
    'MC2': 'Volvo Eicher commercial vehicles limited.',
    'MHR': 'Honda',
    'ML3': 'Mitsubishi Thailand',
    'MM0': 'Mazda',
    'MM8': 'Mazda',
    'MMB': 'Mitsubishi',
    'MMM': 'Chevrolet',
    'MMT': 'Mitsubishi',
    'MNB': 'Ford',
    'MNT': Nissan(),
    'MP1': 'Isuzu',
    'MPA': 'Isuzu',
    'MR0': 'Toyota',
    'MRH': 'Honda',
    'MS0': 'KIA Myanmar',
    'NLE': 'Mercedes-Benz Turk Truck',
    'NM0': 'Ford Otosan',
    'NM4': 'Tofas Turk',
    'NMT': 'Toyota',
    'PE1': 'Ford',
    'PE3': 'Mazda',
    'PL1': 'Proton',
    'SAD': 'Jaguar',
    'SAJ': 'Jaguar',
    'SAL': 'Land Rover',
    'SAR': 'Rover',
    'SAT': 'Triumph',
    'SB1': 'Toyota',
    'SBM': 'Mclaren',
    'SCA': 'Rolls Royce',
    'SCB': 'Bentley',
    'SCC': 'Lotus Cars',
    'SCE': 'DeLorean',
    'SCF': 'Aston Martin Lagonda Limited',
    'SDB': 'Peugeot UK',
    'SFD': 'Alexander Dennis',
    'SHH': 'Honda',
    'SHS': 'Honda',
    'SJK': Nissan('Infiniti'),
    'SJN': Nissan(),
    'SKF': Opel(),
    'SU9': 'Solaris Bus & Coach',
    'TCC': 'Micro Compact Car AG (SMART 1998-1999)',
    'TDM': 'QUANTYA Swiss Electric Movement',
    'TK9': 'SOR',
    'TM9': 'Škoda trolleybuses',
    'TMA': 'Hyundai',
    'TMB': 'Škoda',
    'TMK': 'Karosa',
    'TMP': 'Škoda trolleybuses',
    'TMT': 'Tatra',
    'TN9': 'Karosa',
    'TRA': 'Ikarus Bus',
    'TRU': 'Audi',
    'TSE': 'Ikarus Egyedi Autobuszgyar',
    'TSM': 'Suzuki',
    'U5Y': 'Kia',
    'UU': 'Dacia',
    'UU1': Renault('Renault Dacia'),
    'VA0': 'ÖAF',
    'VF1': Renault(),
    'VF2': Renault(),
    'VF3': 'Peugeot',
    'VF4': 'Talbot',
    'VF5': 'Iveco Unic SA',
    'VF6': 'Renault Trucks/Volvo',
    'VF7': 'Citroën',
    'VF8': 'Matra/Talbot/Simca',
    'VF9': 'Bugatti',
    'VFE': 'IvecoBus',
    'VLU': 'Scania',
    'VN1': Opel(),
    'VNE': 'Irisbus',
    'VNK': 'Toyota',
    'VS5': Renault(),
    'VS6': 'Ford',
    'VS9': 'Carrocerias Ayats',
    'VSE': 'Suzuki / Santana Motors',
    'VSK': Nissan(),
    'VSS': 'SEAT',
    'VSX': Opel('Opel'),
    'VSY': Renault(),
    'VV9': 'Tauro Sport Auto',
    'VWG': 'Volkswagen Spain',
    'VWV': 'Volkswagen',
    'VX1': 'Zastava / Yugo',
    'W0L': Opel('Opel/Vauxhall'),
    'W0S': Opel('Opel Special Vehicles'),
    'W04': 'Buick',
    'W09': 'Ruf Automobile',
    'WA1': 'Audi',
    'WAG': 'Neoplan',
    'WAP': 'Alpina',
    'WAU': 'Audi',
    'WB': 'BMW',
    'WBS': 'BMW M',
    'WCD': 'Mercedes-Benz (Sprinter)',
    'WD3': 'Daimler AG (Sprinter)',
    'WD4': 'Daimler AG (Sprinter)',
    'WDA': 'Daimler AG (Sprinter)',
    'WDB': 'Mercedes-Benz',
    'WDC': 'DaimlerChrysler AG/Daimler AG',
    'WDD': 'DaimlerChrysler AG/Daimler AG',
    'WDP': 'Mercedes-Benz (Sprinter)',
    'WDR': 'Mercedes-Benz (Sprinter)',
    'WDY': 'Mercedes-Benz (Sprinter)',
    'WDZ': 'Mercedes-Benz (Sprinter)',
    'WEB': 'EvoBus',
    'WF0': 'Ford of Europe',
    'WJM': 'Iveco',
    'WJR': 'Irmscher',
    'WKK': 'Karl Kässbohrer Fahrzeugwerke',
    'WMA': 'MAN',
    'WME': 'Smart',
    'WMW': 'Mini',
    'WMX': 'DaimlerChrysler AG/Daimler AG',
    'WP0': 'Porsche car',
    'WP1': 'Porsche SUV',
    'WUA': 'Quattro',
    'WV': 'Volkswagen',
    'WV1': 'Volkswagen Commercial Vehicles',
    'WV2': 'Volkswagen Commercial Vehicles',
    'WV3': 'Volkswagen Trucks',
    'WWD': 'Mercedes-Benz',
    'X7L': Renault(),
    'XL9': 'Spyker',
    'XLR': 'DAF Trucks',
    'XMC': 'Mitsubishi (NedCar)',
    'XTA': Lada('AvtoVAZ'),
    'XUF': Opel(),
    'XWF': Opel(),
    'Y6D': Opel(),
    'YH4': 'Fisker',
    'YK1': 'Saab',
    'YS2': 'Scania, Södertälje',
    'YS3': 'Saab',
    'YS4': 'Scania, Katrineholm',
    'YTN': 'Saab NEVS',
    'YV1': 'Volvo Cars',
    'YV2': 'Volvo Trucks',
    'YV3': 'Volvo Buses',
    'YV4': 'Volvo Cars',
    'ZA9': 'Bugatti',
    'ZAC': 'FCA',
    'ZAM': 'Maserati',
    'ZAP': 'Piaggio/Vespa/Gilera',
    'ZAR': 'Alfa Romeo',
    'ZCF': 'Iveco',
    'ZCG': 'Cagiva SpA',
    'ZD4': 'Aprilia',
    'ZDF': 'Ferrari Dino',
    'ZDM': 'Ducati Motor Holdings SpA',
    'ZFA': 'Fiat Automobiles',
    'ZFB': 'Fiat',
    'ZFC': 'Fiat V.I.',
    'ZFF': 'Ferrari',
    'ZGA': 'IvecoBus',
    'ZHW': 'Lamborghini',
    'ZLA': 'Lancia',
    'ZOM': 'OM',
}
